import React, { ReactNode } from 'react';
import type { IdType, RenderModuleType, ValueTypeType, SortOrderType, FixedType } from './base';
export declare type TableUnit = {
    [key: string]: any;
    expand?: boolean;
    children?: Array<TableUnit>;
};
export declare type Pagination = {
    current: number;
    pageSize: number;
};
export declare type Filters = {
    address: any;
    name: any;
};
export declare type Sorter = {
    columns: object;
    columnKey: string;
    field: string;
    order: SortOrderType;
};
export declare type Extra = {
    currentDataSource: object[];
    action: 'sort' | 'paginate';
};
export declare type EditChangeType = (allChangeData: {
    [rowId in IdType]: {
        [dataIndex in IdType]: any;
    };
}, curChangeData: {
    curData: string;
    dataIndex: IdType;
    dataRowId: IdType;
}[], changeType: 'change' | 'delete' | 'add') => void;
export declare type SelectionCity = {
    code?: string;
    name?: string;
    province?: string;
    city?: string;
    area?: string;
    children?: SelectionCity[];
};
export interface TableColumns<T> {
    dataIndex?: keyof T;
    title: string | (() => ReactNode);
    width?: number;
    fixed?: FixedType;
    valueType?: ValueTypeType;
    selection?: {
        label: string;
        value: string;
    }[] | SelectionCity[];
    selectionAsync?: {
        emptyText?: (errorInfo: any) => ReactNode | string;
        isLoadingClose?: boolean;
        data?: (data: string, record: T) => Promise<{
            label: string;
            value: string;
        }[]>;
    };
    className?: string;
    minWidth?: number;
    hidden?: boolean;
    resize?: boolean;
    paddingLeft?: number;
    paddingRight?: number;
    show?: boolean;
    sorter?: boolean;
    sortOrder?: SortOrderType;
    expandCol?: boolean;
    renderModule?: RenderModuleType;
    children?: TableColumns<T>[];
    iconConfig?: {
        icon?: ReactNode;
        onClick?: (colUnit: T) => void;
        width?: number;
    };
    fieldNames?: {
        label: string;
        value: string;
        children: string;
    };
    info?: (text: any, record: T, index: number, width: number) => React.ReactNode;
    render?: (text: any, record: T, index: number, width: number) => React.ReactNode;
}
export interface TableProps<T> {
    rowKey?: string;
    className?: string;
    height?: number;
    width?: number;
    itemHeight?: number;
    itemWidth?: number;
    defaultShowCtx?: string;
    crosswalk?: boolean;
    loading?: boolean;
    columns: Array<TableColumns<T>>;
    dataSource: Array<T>;
    renderModule?: RenderModuleType;
    hoverRowHighlight?: boolean;
    expandConfig?: {
        expandKey?: string;
        onExpandChange?: (key: string) => Promise<T>;
        defaultExpand?: number;
    };
    onChange?: (pagination: Pagination, filters: Filters, sorter: Sorter, extra: Extra) => void;
    rowSelection?: {
        selectedRowKeys: Array<string>;
        onChange: (data: string[], type?: true | false | undefined) => void;
        rowSelectionIconSp?: boolean;
    };
    pagination?: {
        total?: number;
        pageSize?: number;
        current?: number;
        onChange?: (current: number, pageSize: number) => void;
        onShowSizeChange?: (current: number, pageSize: number) => void;
    };
    editableConfig?: {
        editable?: boolean;
        onEditChange?: EditChangeType;
        hoverRowShowDel?: boolean;
        delCb?: (dataRowId: string, data: T) => void;
        showAddBtn?: boolean;
        addCb?: () => Promise<{
            [key in IdType]: any;
        }>;
        customizeConfig?: {
            visible: boolean;
            onCustomizeChange: (dataIndex: string, dataRowId: string, data: T) => void;
        };
        infos?: {
            colId?: IdType;
            rowId?: IdType;
            msg?: string;
            className?: string;
            icon?: string;
            type?: 'error' | 'info' | 'warning';
        }[];
    };
}
declare global {
    interface Window {
        tExcelResize: boolean;
        stopHover: boolean;
        inPopover: boolean;
    }
}
